@@ -1,32 +1,20 @@
-# -*- coding: utf-8 -*-
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2021 Nicolargo <nicolas@nicolargo.com>
+# SPDX-FileCopyrightText: 2022 Nicolas Hennion <nicolas@nicolargo.com>
 #
-# Glances is free software; you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
+# SPDX-License-Identifier: LGPL-3.0-only
 #
-# Glances is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """CPU percent stats shared between CPU and Quicklook plugins."""
 
+import psutil
+
 from glances.logger import logger
 from glances.timer import Timer
 
-import psutil
-
-
-class CpuPercent(object):
 
+class CpuPercent:
     """Get and store the CPU percent."""
 
     def __init__(self, cached_timer_cpu=3):
@@ -57,8 +45,7 @@ class CpuPercent(object):
         If percpu, return the percpu stats"""
         if percpu:
             return self.__get_percpu()
-        else:
-            return self.__get_cpu()
+        return self.__get_cpu()
 
     def get_info(self):
         """Get additional information about the CPU"""
@@ -68,7 +55,7 @@ class CpuPercent(object):
             try:
                 cpu_freq = psutil.cpu_freq()
             except Exception as e:
-                logger.debug('Can not grab CPU information ({})'.format(e))
+                logger.debug(f'Can not grab CPU information ({e})')
             else:
                 if hasattr(cpu_freq, 'current'):
                     self.cpu_info['cpu_hz_current'] = cpu_freq.current
@@ -84,10 +71,10 @@ class CpuPercent(object):
 
     def __get_cpu_name(self):
         # Get the CPU name once from the /proc/cpuinfo file
-        # @TODO: Multisystem...
+        # TODO: Multisystem...
         try:
-            self.cpu_info['cpu_name'] = open('/proc/cpuinfo', 'r').readlines()[4].split(':')[1].strip()
-        except:
+            self.cpu_info['cpu_name'] = open('/proc/cpuinfo').readlines()[4].split(':')[1].strip()
+        except (FileNotFoundError, PermissionError, IndexError, KeyError, AttributeError):
             self.cpu_info['cpu_name'] = 'CPU'
         return self.cpu_info['cpu_name']
 
